pub struct OrderIdentity {
pub instrument_id: InstrumentId,
pub strategy_id: StrategyId,
pub order_side: OrderSide,
pub order_type: OrderType,
}Expand description
Order identity captured at submission time so the dispatch task can build proper order events without consulting the cache.
Fields
instrument_id: InstrumentIdstrategy_id: StrategyIdorder_side: OrderSideorder_type: OrderTypeTrait Implementations
Sourceimpl Clone for OrderIdentity
impl Clone for OrderIdentity
Sourcefn clone(&self) -> OrderIdentity
fn clone(&self) -> OrderIdentity
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OrderIdentity
Sourceimpl Debug for OrderIdentity
impl Debug for OrderIdentity
impl Eq for OrderIdentity
Sourceimpl PartialEq for OrderIdentity
impl PartialEq for OrderIdentity
Sourcefn eq(&self, other: &OrderIdentity) -> bool
fn eq(&self, other: &OrderIdentity) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for OrderIdentity